@@ -23,7 +23,7 @@ from fabric.contrib.files import append, exists
 from fabric.contrib.console import confirm
 from fabric import colors
 
-VERSION = (0, 5, 0)
+VERSION = (0, 5, 1)
 version = ".".join([str(x) for x in VERSION])
 
 NODEPATH = "nodes/"
@@ -211,7 +211,7 @@ def list_roles():
     for role in _get_roles():
         margin_left = _get_margin(len(role['fullname']))
         print("{0}:{1}{2}".format(
-            role['fullname'], margin_left, role['description']))
+            role['fullname'], margin_left, role.get('description', '(no description)')))
 
 @hosts('api')
 def list_roles_detailed():
@@ -641,7 +641,8 @@ def _get_recipes():
     '''Gets all recipes found in the cookbooks/ directory'''
     recipes = []
     for dirname in sorted(
-        [d for d in os.listdir('cookbooks') if not d.startswith('.')]):
+        [d for d in os.listdir('cookbooks') if os.path.isdir(
+            os.path.join('cookbooks', d)) and not d.startswith('.')]):
         recipes.extend(_get_recipes_in_cookbook(dirname))
     return recipes
 
@@ -696,10 +697,12 @@ def _print_role(role, detailed=True):
         print("  Role: {0}".format(role.get('fullname')))
     if detailed:
         print "    description: {0}".format(role.get('description'))
-    print "    default_attributes:"
-    _pprint(role.get('default_attributes'))
-    print "    override_attributes:"
-    _pprint(role.get('override_attributes'))
+    if 'default_attributes' in role:
+      print "    default_attributes:"
+      _pprint(role['default_attributes'])
+    if 'override_attributes' in role:
+      print "    override_attributes:"
+      _pprint(role['override_attributes'])
     print ""
 
 def _get_cookbook_path(cookbook_name):
@@ -708,7 +711,7 @@ def _get_cookbook_path(cookbook_name):
         path = os.path.join(cookbook_path, cookbook_name)
         if os.path.exists(path):
             return path
-    raise IOError('Can\'t find cookbook with name "{0}"'.formatcookbook_name)
+    raise IOError('Can\'t find cookbook with name "{0}"'.format(cookbook_name))
 
 def _pprint(dic):
     '''Prints a dictionary with one indentation level'''
